@@ -1,9 +1,10 @@
+import typing
 from enum import Enum
 
 
 class FlagType(Enum):
     BOOLEAN = bool
     STRING = str
-    OBJECT = dict
+    OBJECT = typing.Union[dict, list]
     FLOAT = float
     INTEGER = int
